@@ -3,41 +3,42 @@ import warnings
 
 import numpy as np
 
-from . import general
-from . import symmetric as symm
-from . import asymmetric as asymm
-from . import plotting
-
+from .functions import general
+from .functions import symmetric as symm
+from .functions import asymmetric as asymm
 from .output import Output
 
+from . import plotting
+
 from .parameter import (
-    ARG_PARAM_MAP, PARAM_SYMBOL_MAP, TARGET_PARAM_MAP,
+    ARG_PARAM_MAP,
+    PARAM_SYMBOL_MAP,
+    TARGET_PARAM_MAP,
     Parameter,
-    is_angle, is_distance, is_frequency,
-    param_for_printing, param_to_command_arg,
-    param_to_config_type
-)
-from .units import (
-    SI_DISTANCE_MAP, SI_FREQ_MAP,
-    standard_units_from_param
-)
-from .utilities import (
-    dummy_return, find_nearest, save_result, quit_print, bug
+    is_angle,
+    is_distance,
+    is_frequency,
+    param_for_printing,
+    param_to_command_arg,
+    param_to_config_type,
 )
+from .units import SI_DISTANCE_MAP, SI_FREQ_MAP, standard_units_from_param
+from .utilities import dummy_return, find_nearest, save_result, quit_print, bug
 
 from . import CONFIG
 
 SingularComputable = namedtuple("SingularComputable", "function arg_calcvs arg_ts")
 
+
 class Handler(object):
     def __init__(self, args, command_line=True):
         self.args = args
         self.cl = command_line
 
         self.target = self.args.compute
-        self.compute_all = (self.args.compute == "all")
+        self.compute_all = self.args.compute == "all"
 
-        self.units_str = ''
+        self.units_str = ""
         if not self.compute_all:
             self.ptarget = TARGET_PARAM_MAP[self.target]
 
@@ -46,16 +47,20 @@ class Handler(object):
             self.units = self.args.units
             self.units_map = None
             if self.args.units is not None:
-                if std_units_of_target == 'm':
+                if std_units_of_target == "m":
                     if self.args.units not in SI_DISTANCE_MAP:
-                        quit_print("ERROR: Invalid output units given for "
-                                   f"{self.target}", self.cl)
+                        quit_print(
+                            "ERROR: Invalid output units given for " f"{self.target}",
+                            self.cl,
+                        )
 
                     self.units_map = SI_DISTANCE_MAP
                 elif std_units_of_target == "Hz":
                     if self.args.units not in SI_FREQ_MAP:
-                        quit_print("ERROR: Invalid output units given for "
-                                   f"{self.target}", self.cl)
+                        quit_print(
+                            "ERROR: Invalid output units given for " f"{self.target}",
+                            self.cl,
+                        )
 
                     self.units_map = SI_FREQ_MAP
                 elif std_units_of_target == "radians":
@@ -64,8 +69,10 @@ class Handler(object):
                     elif args.units.lower() in ("rad", "rads", "radians"):
                         self.units = (dummy_return, "radians")
                     else:
-                        quit_print("ERROR: Invalid output units given for "
-                                   f"{self.target}", self.cl)
+                        quit_print(
+                            "ERROR: Invalid output units given for " f"{self.target}",
+                            self.cl,
+                        )
             else:
                 config_type = param_to_config_type(self.ptarget)
                 if config_type is None:
@@ -87,21 +94,27 @@ class Handler(object):
             if isinstance(self.units, str):
                 self.units_str = self.units
             else:
-                if (not isinstance(self.units, tuple) or
-                    not isinstance(self.units[1], str)):
-                    bug("\nBug encountered! Unrecognised type of parsed units"
-                        f"passed to handler: {self.units}", self.cl)
+                if not isinstance(self.units, tuple) or not isinstance(
+                    self.units[1], str
+                ):
+                    bug(
+                        "\nBug encountered! Unrecognised type of parsed units"
+                        f"passed to handler: {self.units}",
+                        self.cl,
+                    )
 
                 self.units_str = self.units[1]
         else:
             if self.args.units is not None:
-                print("WARNING: -u option is not yet supported for a compute target of all, ignoring "
-                      "it and using units from config file for now.")
+                print(
+                    "WARNING: -u option is not yet supported for a compute target of all, ignoring "
+                    "it and using units from config file for now."
+                )
 
             self.units = {}
             for k, v in CONFIG["units"].items():
                 v_ = v.strip()
-                if k == 'gouy' or k == 'divergence':
+                if k == "gouy" or k == "divergence":
                     if v_.lower() in ("deg", "degrees"):
                         self.units[k] = (np.degrees, "degrees")
                     else:
@@ -110,17 +123,17 @@ class Handler(object):
                     self.units[k] = v.strip()
 
         self.symmetric = not (
-            self.args.stability_itm is not None or
-            self.args.stability_etm is not None or
-            self.args.curvature_itm is not None or
-            self.args.curvature_etm is not None
+            self.args.stability_itm is not None
+            or self.args.stability_etm is not None
+            or self.args.curvature_itm is not None
+            or self.args.curvature_etm is not None
         )
 
         self.all_funcs_map = {}
         func_maps = [
             general.FUNC_DEPENDENCIES_MAP,
             symm.FUNC_DEPENDENCIES_MAP,
-            asymm.FUNC_DEPENDENCIES_MAP
+            asymm.FUNC_DEPENDENCIES_MAP,
         ]
         for fm in func_maps:
             self.all_funcs_map.update(fm)
@@ -161,8 +174,7 @@ class Handler(object):
         given = {}
 
         for argname, value in vars(self.args).items():
-            if (value is not None and
-                argname in ARG_PARAM_MAP.keys()):
+            if value is not None and argname in ARG_PARAM_MAP.keys():
                 given[ARG_PARAM_MAP[argname]] = value
 
         return given
@@ -178,7 +190,8 @@ class Handler(object):
     def all_required_arguments(self, ptarget=None):
         all_reqd = []
 
-        if ptarget is None: ptarget = self.ptarget
+        if ptarget is None:
+            ptarget = self.ptarget
 
         for _, (reqd_params, return_param) in self.all_funcs_map.items():
             if return_param == ptarget:
@@ -189,7 +202,8 @@ class Handler(object):
     def all_functions_from_target(self, ptarget=None):
         targets = {}
 
-        if ptarget is None: ptarget = self.ptarget
+        if ptarget is None:
+            ptarget = self.ptarget
 
         for func, (reqd_params, return_param) in self.func_dependency_map.items():
             if return_param == ptarget:
@@ -197,24 +211,31 @@ class Handler(object):
 
         return targets
 
+    def all_targets_in_dependency_map(self):
+        targets = set()
+
+        for _, return_param in self.func_dependency_map.values():
+            targets.add(return_param)
+
+        return targets
+
     def filter_computable(self, targets_map):
         to_compute = None
         arguments = None
         args_for_doplot = []
 
         for func, (reqd_params, _) in targets_map.items():
-            params_diff = set(reqd_params).difference(
-                self.given_physical_args.keys()
-            )
+            params_diff = set(reqd_params).difference(self.given_physical_args.keys())
             if not params_diff:
                 to_compute = func
-                arguments = (self.given_physical_args[p].calcv
-                             for p in reqd_params)
+                arguments = (self.given_physical_args[p].calcv for p in reqd_params)
                 for p in reqd_params:
                     args_for_doplot.append(
-                        (self.given_physical_args[p].v,
-                        p,
-                        self.given_physical_args[p].units)
+                        (
+                            self.given_physical_args[p].v,
+                            p,
+                            self.given_physical_args[p].units,
+                        )
                     )
                 break
 
@@ -227,15 +248,35 @@ class Handler(object):
         to_compute = {}
         targets_to_compute = set()
 
+        # Here we want to find all the functions of each target type that we CAN compute
+        # from the given args and add them to our computables container to avoid adding
+        # the wrong function later on during chained target calls
+        if self.compute_all:
+            specified_ = self.specified()
+            all_targets = self.all_targets_in_dependency_map()
+            for target in all_targets:
+                if target in self.given_physical_args:
+                    continue
+
+                funcs_from_target = self.all_functions_from_target(target)
+
+                for func, (reqd_params, return_param) in funcs_from_target.items():
+                    pdiff = set(reqd_params).difference(specified_.keys())
+                    if not pdiff:
+                        to_compute[func] = (
+                            (specified_[p].calcv for p in reqd_params),
+                            return_param,
+                        )
+                        targets_to_compute.add(return_param)
+                        break
+
         for func, (reqd_params, return_param) in self.func_dependency_map.items():
             if func in to_compute or return_param in targets_to_compute:
                 continue
 
             specified = self.specified()
 
-            params_diff = set(reqd_params).difference(
-                specified.keys()
-            )
+            params_diff = set(reqd_params).difference(specified.keys())
 
             if not params_diff:
                 if func not in to_compute:
@@ -243,15 +284,16 @@ class Handler(object):
                         continue
 
                     to_compute[func] = (
-                        (specified[p].calcv
-                        for p in reqd_params),
-                        return_param
+                        (specified[p].calcv for p in reqd_params),
+                        return_param,
                     )
                     targets_to_compute.add(return_param)
             else:
                 if func not in self.chain_triggered and return_param not in specified:
                     self.chain_triggered.add(func)
-                    sc = self.chained_target(self.all_functions_from_target(return_param))
+                    sc = self.chained_target(
+                        self.all_functions_from_target(return_param)
+                    )
                     if sc is not None and sc.function not in to_compute:
                         to_compute[sc.function] = (sc.arg_calcvs, return_param)
                         targets_to_compute.add(return_param)
@@ -271,14 +313,30 @@ class Handler(object):
                 if rtn_param in reqd_params:
                     try:
                         vals = [val for val in values]
-                        func_result[rtn_param] = func(*vals)
+                        with warnings.catch_warnings():
+                            warnings.simplefilter("ignore", category=RuntimeWarning)
+
+                            try:
+                                # FIXME losing is_dual information here, need to pass it on
+                                result, _ = func(*vals)
+                                func_result[rtn_param] = result
+                            except ZeroDivisionError:
+                                quit_print(
+                                    "ERROR: Division by zero occurred in function: "
+                                    f"{func}",
+                                    self.cl,
+                                )
                     except Exception as e:
-                        func_params = tuple(param_to_command_arg(p).strip('-')
-                                       for p in reqd_params)
+                        func_params = tuple(
+                            param_to_command_arg(p).strip("-") for p in reqd_params
+                        )
                         fp = ", ".join(func_params)
-                        bug("\nBug encountered! The following error occurred:"
-                            f"\n\n\t\"{e}\"\n\nwhen calling {func.__name__}({fp}) "
-                            f"with:\n\t{vals}.", self.cl)
+                        bug(
+                            "\nBug encountered! The following error occurred:"
+                            f'\n\n\t"{e}"\n\nwhen calling {func.__name__}({fp}) '
+                            f"with:\n\t{vals}.",
+                            self.cl,
+                        )
 
             if func_result:
                 break
@@ -291,7 +349,7 @@ class Handler(object):
         args_for_plot = []
         # make new entries in the given map from the results of this function call
         for param, values in func_result.items():
-            self.chained_args[param] = PhysicalQuantity(values, values, '')
+            self.chained_args[param] = PhysicalQuantity(values, values, "")
 
         # finally get the function to compute using the new given args dictionary
         func_to_compute = None
@@ -300,9 +358,7 @@ class Handler(object):
         specified = self.specified()
 
         for target_func, (reqd_params, _) in targets.items():
-            params_diff = set(reqd_params).difference(
-                specified.keys()
-            )
+            params_diff = set(reqd_params).difference(specified.keys())
 
             if not params_diff:
                 func_to_compute = target_func
@@ -310,18 +366,15 @@ class Handler(object):
 
                 # grab all the required parameters for the function to be computed
                 # as well as the parameter which started the chained calls
-                needed_args = list(reqd_params) + list(set
-                        (specified.keys()
-                    ).difference(reqd_params))
+                needed_args = list(reqd_params) + list(
+                    set(specified.keys()).difference(reqd_params)
+                )
 
                 for p in needed_args:
-                    if p in func_result: continue
+                    if p in func_result:
+                        continue
 
-                    args_for_plot.append((
-                        specified[p].v,
-                        p,
-                        specified[p].units
-                    ))
+                    args_for_plot.append((specified[p].v, p, specified[p].units))
                 break
 
         return SingularComputable(func_to_compute, arguments, args_for_plot)
@@ -330,36 +383,36 @@ class Handler(object):
         if self.args.find is None:
             return None
 
-        if self.args.find.fromvar == 'x':
-            if self.args.find.condition == '=':
+        if self.args.find.fromvar == "x":
+            if self.args.find.condition == "=":
                 idx = find_nearest(
-                    vars(self.args)[self.args.find.var].v,
-                    self.args.find.value
+                    vars(self.args)[self.args.find.var].v, self.args.find.value
                 )
                 return result[idx]
         else:
-            if self.args.find.condition == '=':
+            if self.args.find.condition == "=":
                 idx = find_nearest(result, self.args.find.value)
                 return vars(self.args)[self.args.find.var].v[idx]
 
     def print_found_conditions(self, found):
-        if found is None: return
+        if found is None:
+            return
 
         afind = self.args.find
-        if afind.fromvar == 'x':
-            print(f"At {afind.var} = {afind.value} {afind.units}, "
-                  f"{self.target} = {found} {self.units_str}")
-        else:
-            print(f"At {self.target} = {afind.value} {self.units_str}, "
-                  f"{afind.var} = {found} {afind.units}")
-
-    def _print_result(self, result, computable):
-        if not isinstance(result, np.ndarray) or result.size == 2:
+        if afind.fromvar == "x":
             print(
-                "Given [{}SYMMETRIC CAVITY]:".format(
-                    '' if self.symmetric else 'A'
-                )
+                f"At {afind.var} = {afind.value} {afind.units}, "
+                f"{self.target} = {found} {self.units_str}"
             )
+        else:
+            print(
+                f"At {self.target} = {afind.value} {self.units_str}, "
+                f"{afind.var} = {found} {afind.units}"
+            )
+
+    def _print_result(self, result, computable, is_dual):
+        if not isinstance(result, np.ndarray) or result.size == 2:
+            print("Given [{}SYMMETRIC CAVITY]:".format("" if self.symmetric else "A"))
 
             for argvals, argparam, argunits in computable.arg_ts:
                 if not argunits:
@@ -367,12 +420,37 @@ class Handler(object):
                 print(f"\t{param_for_printing(argparam)} = {argvals} {argunits}")
 
             print("\nComputed:")
-            print(f"\t{param_for_printing(self.ptarget)} = "
-                  f"{result} {self.units_str}")
+            # TODO some cleaning up here - move common printing code to separate function
+            if self.args.dps is None:
+                if not is_dual:
+                    print(
+                        f"\t{param_for_printing(self.ptarget)} = "
+                        f"{result} {self.units_str}"
+                    )
+                else:
+                    print(
+                        f"\t{param_for_printing(self.ptarget)}:\n"
+                        f"\t\tLower Quadrant = {result[0]} {self.units_str}, "
+                        f"Upper Quadrant = {result[1]} {self.units_str}"
+                    )
+            else:
+                if not is_dual:
+                    print(
+                        f"\t{param_for_printing(self.ptarget)} = "
+                        f"{np.round(result, self.args.dps)} {self.units_str}"
+                    )
+                else:
+                    print(
+                        f"\t{param_for_printing(self.ptarget)}:\n"
+                        f"\t\tLower Quadrant = {np.round(result[0], self.args.dps)} {self.units_str}, "
+                        f"Upper Quadrant = {np.round(result[1], self.args.dps)} {self.units_str}"
+                    )
         else:
             if not self.args.plot and self.args.outputfile is None:
-                quit_print("NOTE: Use --plot to display the computed results and/or "
-                           "--out to save these results to a file.")
+                quit_print(
+                    "NOTE: Use --plot to display the computed results and/or "
+                    "--out to save these results to a file."
+                )
 
     def run(self):
         out = None
@@ -404,28 +482,28 @@ class Handler(object):
                         msg += param_to_command_arg(param)
                     if param != reqd_params[-1]:
                         msg += " AND "
-            msg += ("\nOR a combination of parameters which allows one of "
-                    "the above sets to be computed.")
+            msg += (
+                "\nOR a combination of parameters which allows one of "
+                "the above sets to be computed."
+            )
             quit_print(msg, self.cl)
 
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=RuntimeWarning)
 
             try:
+                result, is_dual = computable.function(*computable.arg_calcvs)
                 if isinstance(self.units, tuple):
-                    result = self.units[0](computable.function(
-                        *computable.arg_calcvs
-                    ))
+                    result = self.units[0](result)
                 else:
                     if self.units_map is not None:
-                        result = computable.function(
-                            *computable.arg_calcvs
-                        ) / self.units_map[self.units]
-                    else:
-                        result = computable.function(*computable.arg_calcvs)
+                        result /= self.units_map[self.units]
             except ZeroDivisionError:
-                quit_print("ERROR: Division by zero occurred in function: "
-                           f"{computable.function}", self.cl)
+                quit_print(
+                    "ERROR: Division by zero occurred in function: "
+                    f"{computable.function}",
+                    self.cl,
+                )
 
         if not self.cl:
             given_dict = {}
@@ -436,34 +514,29 @@ class Handler(object):
 
             return Output(
                 self.ptarget,
-                {self.ptarget : (result, "")}, given_dict
+                {self.ptarget: (result, self.units_str, is_dual)},
+                given_dict,
             )
 
         found = self.find_conditions(result)
         self.print_found_conditions(found)
         xylines = None
         if found is not None:
-            if self.args.find.fromvar == 'y':
+            if self.args.find.fromvar == "y":
                 xylines = (found, self.args.find.value)
             else:
                 xylines = (self.args.find.value, found)
 
-        self.__plot(
-            (result, self.ptarget, self.units_str),
-            xylines,
-            *computable.arg_ts
-        )
+        self.__plot((result, self.ptarget, self.units_str), xylines, *computable.arg_ts)
 
         save_result(result, self.args.outputfile)
-        self._print_result(result, computable)
+        self._print_result(result, computable, is_dual)
 
     def __run_all_target(self):
         computables = self.filter_computables()
 
         if self.cl:
-            print("Given [{}SYMMETRIC CAVITY]:".format(
-                '' if self.symmetric else 'A'
-            ))
+            print("Given [{}SYMMETRIC CAVITY]:".format("" if self.symmetric else "A"))
         else:
             results = {}
             given = {}
@@ -487,24 +560,39 @@ class Handler(object):
             if rtn_param in self.given_physical_args:
                 continue
 
-            result = func(*args)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=RuntimeWarning)
+
+                try:
+                    result, is_dual = func(*args)
+                except ZeroDivisionError:
+                    quit_print(
+                        "ERROR: Division by zero occurred in function: " f"{func}",
+                        self.cl,
+                    )
 
             if rtn_param in done:
                 prev_func, prev_result = done[rtn_param]
                 if type(result) == type(prev_result):
                     if not np.allclose(result, prev_result):
-                        func_params = tuple(param_to_command_arg(p).strip('-')
-                                       for p in self.func_dependency_map[func][0])
-                        prev_func_params = tuple(param_to_command_arg(p).strip('-')
-                                            for p in self.func_dependency_map[prev_func][0])
+                        func_params = tuple(
+                            param_to_command_arg(p).strip("-")
+                            for p in self.func_dependency_map[func][0]
+                        )
+                        prev_func_params = tuple(
+                            param_to_command_arg(p).strip("-")
+                            for p in self.func_dependency_map[prev_func][0]
+                        )
 
                         fp = ", ".join(func_params)
                         pfp = ", ".join(prev_func_params)
 
-                        msg = ("\nBug encountered! Differing results when computing "
-                              f"\"{param_for_printing(rtn_param)}\" using two different methods:\n\n"
-                              f"\tf({fp}) = {result}\n"
-                              f"\tf({pfp}) = {prev_result}")
+                        msg = (
+                            "\nBug encountered! Differing results when computing "
+                            f'"{param_for_printing(rtn_param)}" using two different methods:\n\n'
+                            f"\tf({fp}) = {result}\n"
+                            f"\tf({pfp}) = {prev_result}"
+                        )
                         bug(msg, self.cl)
                 continue
 
@@ -522,9 +610,30 @@ class Handler(object):
                 ustr = standard_units_from_param(rtn_param)
 
             if self.cl:
-                print(f"\t{param_for_printing(rtn_param)} = {result} {ustr}")
+                # TODO some cleaning up here - move common printing code to separate function
+                if self.args.dps is None:
+                    if not is_dual:
+                        print(f"\t{param_for_printing(rtn_param)} = {result} {ustr}")
+                    else:
+                        print(
+                            f"\t{param_for_printing(rtn_param)}:\n"
+                            f"\t\tLower Quadrant = {result[0]} {ustr}, "
+                            f"Upper Quadrant = {result[1]} {ustr}"
+                        )
+                else:
+                    if not is_dual:
+                        print(
+                            f"\t{param_for_printing(rtn_param)} = "
+                            f"{np.round(result, self.args.dps)} {ustr}"
+                        )
+                    else:
+                        print(
+                            f"\t{param_for_printing(rtn_param)}:\n"
+                            f"\t\tLower Quadrant = {np.round(result[0], self.args.dps)} {ustr}, "
+                            f"Upper Quadrant = {np.round(result[1], self.args.dps)} {ustr}"
+                        )
             else:
-                results[rtn_param] = (result, ustr)
+                results[rtn_param] = (result, ustr, is_dual)
 
             done[rtn_param] = func, result
 
@@ -532,7 +641,8 @@ class Handler(object):
             return Output("all", results, given)
 
     def __plot(self, result, xylines, *args):
-        if not self.args.plot: return
+        if not self.args.plot:
+            return
 
         # perform some checks first
         const_params = []
@@ -560,14 +670,18 @@ class Handler(object):
                 axes_labels.append(label)
 
             return plotting.density_plot(
-                X, Y, Z,
+                X,
+                Y,
+                Z,
                 xlabel=axes_labels[0],
                 ylabel=axes_labels[1],
                 zlabel=axes_labels[2],
-                xlim=self.args.xlim, ylim=self.args.ylim, zlim=self.args.zlim,
+                xlim=self.args.xlim,
+                ylim=self.args.ylim,
+                zlim=self.args.zlim,
                 log=self.args.loglog,
                 cmap=self.args.cmap,
-                filename=self.args.saveplot
+                filename=self.args.saveplot,
             )
 
         # normal plot
@@ -584,14 +698,17 @@ class Handler(object):
             y = [y]
         else:
             if y.shape[0] != 2:
-                bug(f"\nBug encountered! Unrecognised result dimensions: {y.shape} "
-                    f"when trying to plot \"{param_for_printing(y_param_id)}\".", self.cl)
+                bug(
+                    f"\nBug encountered! Unrecognised result dimensions: {y.shape} "
+                    f'when trying to plot "{param_for_printing(y_param_id)}".',
+                    self.cl,
+                )
             else:
                 if self.args.saveplot is not None:
-                    split_ext = self.args.saveplot.split('.')
+                    split_ext = self.args.saveplot.split(".")
                     fname = [
                         split_ext[0] + "_lowerquad." + split_ext[1],
-                        split_ext[0] + "_upperquad." + split_ext[1]
+                        split_ext[0] + "_upperquad." + split_ext[1],
                     ]
 
         for i, yi in enumerate(y):
@@ -599,13 +716,16 @@ class Handler(object):
             if len(y) > 1:
                 legend += " (lower quad)" if not i else " (upper quad)"
             if const_params:
-                legend += "{}with ".format('\n' if len(const_params) > 1 else ' ')
+                legend += "{}with ".format("\n" if len(const_params) > 1 else " ")
                 legend += ", ".join(
-                    ["{} = {} {}".format(
-                        PARAM_SYMBOL_MAP[p_id],
-                        p,
-                        p_u if p_u else standard_units_from_param(p_id)
-                    ) for p, p_id, p_u in const_params]
+                    [
+                        "{} = {} {}".format(
+                            PARAM_SYMBOL_MAP[p_id],
+                            p,
+                            p_u if p_u else standard_units_from_param(p_id),
+                        )
+                        for p, p_id, p_u in const_params
+                    ]
                 )
 
             for param, param_id, param_units in args:
@@ -615,10 +735,17 @@ class Handler(object):
                         xlabel += f" [{param_units}]"
 
                     plotting.plot(
-                        param, yi, xline=xylines[0], yline=xylines[1],
-                        xlabel=xlabel, ylabel=ylabel, legend=legend,
-                        xlim=self.args.xlim, ylim=self.args.ylim,
-                        logx=self.args.semilogx, logy=self.args.semilogy,
-                        filename=fname[i]
+                        param,
+                        yi,
+                        xline=xylines[0],
+                        yline=xylines[1],
+                        xlabel=xlabel,
+                        ylabel=ylabel,
+                        legend=legend,
+                        xlim=self.args.xlim,
+                        ylim=self.args.ylim,
+                        logx=self.args.semilogx,
+                        logy=self.args.semilogy,
+                        filename=fname[i],
                     )
                     break
